/*  FSLView - 2D/3D Interactive Image Viewer

    Authors:    Rama Aravind Vorray
		James Saunders
		David Flitney 
		Mark Jenkinson
		Stephen Smith

    FMRIB Image Analysis Group

    Copyright (C) 2002-2003 University of Oxford  */

/*  CCOPYRIGHT */

#if !defined(VTKTOOLBAR_H)
#define VTKTOOLBAR_H

#include "vtktoolbarbase.h"

class VTKProperties;

class VTKToolbar: public QWidget, public Ui::VTKToolbarBase
{
  Q_OBJECT

public:
  VTKToolbar(QWidget *, VTKProperties&);

private slots:
  void on_threshold_valueChanged(int);
  void on_clipping_stateChanged(int);

private:
  VTKProperties &m_props;
};

#endif
